==> haskell-versions-6.0.8-66.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 versions
version:              6.0.8
visibility:           public
id:                   versions-6.0.8-92YzNRw75H81qL5SetCKLs
key:                  versions-6.0.8-92YzNRw75H81qL5SetCKLs
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  45bdaad336ab9f744f71b46685c3f3f8
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-versions
hs-libraries:         HSversions-6.0.8-92YzNRw75H81qL5SetCKLs
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-versions-6.0.8-67-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 versions
version:              6.0.8
visibility:           public
id:                   versions-6.0.8-CXPX8fyXIhe6oYqXFQYdjw
key:                  versions-6.0.8-CXPX8fyXIhe6oYqXFQYdjw
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  fdab98f654a6e171e73426b017877c00
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-versions
hs-libraries:         HSversions-6.0.8-CXPX8fyXIhe6oYqXFQYdjw
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
